@@ -95,6 +95,12 @@ urlpatterns = patterns('',
         name='sentry-manage-project-plugins'),
     url(r'^account/projects/(?P<project_id>[\w_-]+)/plugins/(?P<slug>[\w_-]+)/$', projects.configure_project_plugin,
         name='sentry-configure-project-plugin'),
+    url(r'^account/projects/(?P<project_id>[\w_-]+)/plugins/(?P<slug>[\w_-]+)/reset/$', projects.reset_project_plugin,
+        name='sentry-reset-project-plugin'),
+    url(r'^account/projects/(?P<project_id>[\w_-]+)/plugins/(?P<slug>[\w_-]+)/disable/$', projects.disable_project_plugin,
+        name='sentry-disable-project-plugin'),
+    url(r'^account/projects/(?P<project_id>[\w_-]+)/plugins/(?P<slug>[\w_-]+)/enable/$', projects.enable_project_plugin,
+        name='sentry-enable-project-plugin'),
     url(r'^account/projects/(?P<project_id>[\w_-]+)/remove/$', projects.remove_project,
         name='sentry-remove-project'),
 
